#!/usr/bin/python3

# ------------------------------------------------------------------------------
# Functions for the practical sessions of Aerospace Propulsion (AERO0014)
# 
# Authors:
#   Thomas Lambert  <t.lambert@uliege.be>
#   Koen Hillewaert <koen.hillewaert@uliege.be>
# Aerospace and Mechanics Department (A&M), ULiège
# ------------------------------------------------------------------------------

from numpy import *

R = 287.1
gamma = 1.4

pRef = 101325
TRef = 288

# ------------------------------------------------------------------------------
# total-to-static temperature ratio from Mach number and heat capacity ratio
# ------------------------------------------------------------------------------
def TtOverT(M,gamma):
    return 1 + (gamma-1)/2*M*M

# ------------------------------------------------------------------------------
# total-to-static pressure ratio from Mach number and heat capacity ratio
# ------------------------------------------------------------------------------
def ptOverp(M,gamma):
    return pow(TtOverT(M,gamma),gamma/(gamma-1))

# ------------------------------------------------------------------------------
# choking mass flow
# ------------------------------------------------------------------------------
def chokingMassFlow(pt,Tt,R,gamma,A):
    return pt/sqrt(R*Tt)*sqrt(gamma)*pow(2/(gamma+1),(gamma+1)/2/(gamma-1))*A

# ------------------------------------------------------------------------------
# corrected/reduced mass flow 
# ------------------------------------------------------------------------------
def correctedMassFlow(pt,Tt,mFlow):
    return mFlow*(pRef/pt)*sqrt(Tt/TRef)



# ------------------------------------------------------------------------------
# return the heat capacity by from interpolation on digitized data.
# T = temperature in [K]
# f = fuel-to-air ratio
# result in J/kg.K
# Caveat: not to be used with tables 
# ------------------------------------------------------------------------------

from heatCapacity import *
from scipy import interpolate

CpIfoTAndFar = interpolate.interp2d(CpFar,CpTemp,CpValues,kind='cubic')

def findCp(T,far):
    return CpIfoTAndFar(far,T)[0]


